#
# Dyn_to_Morphs
#
# This script will take the selected prop and convert a cloth simulation 
# into a series of morphs. It will then turn off the dynamics, and apply
# these morphs in the correct frames. The resulting file can be used in
# Carrara, or a similar application, to mimic dynamic cloth.
#
# (c) Copyright 2005 by Dale Tacy - 2005-11-14
#
import poser
import string

def Dyn_to_Morphs():	
	scene = poser.Scene()
	intframenum = scene.NumFrames()
	
	actor = scene.CurrentActor()

	if actor.IsProp():
	
		try:
			scene.SetFrame(0)
			actor.SetParameter("Dynamics", 1.0)
		
			# Check for existing Dyn morphs. Zero, Hide, and Rename.
			to_rename = []

			# Step through frames
			for ps in actor.Parameters():

				if ps.IsMorphTarget():			

					# Check Name & Delete if Dyn_Frame
					if ps.Name().find("Dyn_Frame") <> -1:
						to_rename.append(ps)

			for intframe in range(intframenum):

				scene.SetFrame(intframe)

				for ps in to_rename:
					ps.SetValue(0)
					ps.SetHidden(1)
					ps.SetName("Dyn_Garbage")

			# Now onto setting up the Dyn_Frames
			morphname = "Dyn_Frame_0"
			prevname = "Dyn_Frame_0"

			# Spawn Morphs
			for intframe in range(intframenum):

				# Go to the frame
				scene.SetFrame(intframe)

				# Create Morph Target
				morphname = "Dyn_Frame_" + str(intframe)
				actor.SpawnTarget(morphname)

			# Set all animation steps to constant value for new morphs
			actor.SetRangeConstant(0,intframenum-1)

			morphname = "Dyn_Frame_0"
			prevname = "Dyn_Frame_0"

			# Set Morphs
			for intframe in range(intframenum):

				# Go to the frame
				scene.SetFrame(intframe)

				# Turn off Dynamics
				actor.SetParameter("Dynamics", 0.0)

				# Turn on Morph 
				morphname = "Dyn_Frame_" + str(intframe)
				actor.SetParameter(morphname, 1.0)

				# Turn off all other DynFrame morphs
				for intframe2 in range(intframenum):
					prevname = "Dyn_Frame_" + str(intframe2)
					if prevname<>morphname:
						actor.SetParameter(prevname, 0.0)
		except:
			print "Dyn_to_Morphs Failed - Prop does not have Dynamics!\n\n"
			print "Exiting Dyn_to_Morphs\n\n"
				
	else:
		print "Dyn_to_Morphs Failed - Actor Selected is not a Prop!\n\n"
		print "Exiting Dyn_to_Morphs\n\n"

Dyn_to_Morphs()




